@@ -484,6 +484,17 @@ class IcePAPAxis:
         ans = self.send_cmd('?VER INFO')
         return FirmwareVersion(ans, True)
 
+    @property
+    def fver(self):
+        """
+        Get the only driver version 'axis:?VER'
+        (IcePAP user manual pag. 144).
+
+        :return: float
+        """
+        ans = self.send_cmd('?VER')[0]
+        return float(ans)
+
     @property
     def name(self):
         """
